@@ -49,7 +49,8 @@ class TestMultiReferenceProperty(TestBetamax):
 
         # reference property instance holding the value
         part_instance = self.part_model.instance()
-        self.ref = find(part_instance.properties, lambda p: p.model_id == self.ref_prop_model.id)
+        self.ref = find(part_instance.properties,
+                        lambda p: p.model_id == self.ref_prop_model.id)  # type: MultiReferenceProperty2
 
     def tearDown(self):
         self.target_model.delete()
@@ -91,14 +92,6 @@ class TestMultiReferenceProperty(TestBetamax):
         # testing
         self.assertTrue(len(self.ref.value) >= 2)
 
-    def test_referencing_a_part_not_in_a_list(self):
-        # setUp
-        front_wheel = self.project.part('Front Wheel')
-
-        # testing
-        with self.assertRaises(ValueError):
-            self.ref.value = front_wheel
-
     def test_referencing_a_list_with_no_parts(self):
         # setUp
         fake_part = [15, 21, 26]
@@ -216,8 +209,6 @@ class TestMultiReferenceProperty(TestBetamax):
         diameter_property = self.float_prop  # decimal property
         spokes_property = self.integer_prop  # integer property
         rim_material_property = self.char_prop  # single line text
-        import datetime
-        new_year_2020 = datetime.datetime(year=2020, month=1, day=1)
 
         self.ref_prop_model.set_prefilters(
             property_models=[diameter_property,
@@ -229,7 +220,7 @@ class TestMultiReferenceProperty(TestBetamax):
             values=[30.5,
                     7,
                     'Al',
-                    new_year_2020,
+                    self.time,
                     'Michelin',
                     True],
             filters_type=[FilterType.GREATER_THAN_EQUAL,
@@ -250,7 +241,7 @@ class TestMultiReferenceProperty(TestBetamax):
         self.assertIn("{}:{}:{}".format(rim_material_property.id, 'Al', FilterType.CONTAINS), filters)
         self.assertIn("{}:{}:{}".format(self.bool_prop.id, 'true', FilterType.EXACT), filters)
         self.assertIn("{}:{}:{}".format(self.ssl_prop.id, 'Michelin', FilterType.CONTAINS), filters)
-        self.assertIn("{}:{}:{}".format(self.datetime_prop.id, new_year_2020, FilterType.GREATER_THAN_EQUAL),
+        self.assertIn("{}:{}:{}".format(self.datetime_prop.id, self.time, FilterType.GREATER_THAN_EQUAL),
                       filters)
 
     def test_set_prefilters_on_reference_property_with_excluded_propmodels_and_validators(self):
