@@ -1,7 +1,8 @@
 from unittest import TestCase
 
-from pykechain.enums import (WidgetTypes, ShowColumnTypes, NavigationBarAlignment, FilterType, ProgressBarColors,
-                             Category, LinkTargets, KEChainPages, WidgetTitleValue)
+from pykechain.enums import (WidgetTypes, ShowColumnTypes, FilterType, ProgressBarColors,
+                             Category, LinkTargets, KEChainPages, WidgetTitleValue, Alignment, ActivityType,
+                             CardWidgetLinkValue, CardWidgetLinkTarget, ImageFitValue)
 from pykechain.exceptions import IllegalArgumentError, NotFoundError
 from pykechain.models import Activity2
 from pykechain.models.widgets import (
@@ -55,15 +56,6 @@ class TestSetTitle(TestCase):
         self.assertEqual(title_in, meta['customTitle'])
         self.assertEqual(WidgetTitleValue.NO_TITLE, meta['showTitleValue'])
 
-    def test_custom_title(self):
-        custom_title = 'custom title'
-        meta, title = _set_title(dict(), custom_title=custom_title)
-
-        self.assertEqual(custom_title, title)
-
-        with self.assertWarns(PendingDeprecationWarning):
-            _set_title(dict(), custom_title=custom_title)
-
     def test_default_title(self):
         default = 'default title'
 
@@ -269,11 +261,19 @@ class TestWidgetManagerInActivity(TestBetamax):
         self.assertIsInstance(widget, PropertygridWidget)
         self.assertEqual(len(self.wm), 1 + 1)
 
+    def test_add_attachment_widget(self):
+        picture_instance = self.project.part('Bike').property('Picture')
+        widget = self.wm.add_attachmentviewer_widget(
+            attachment_property=picture_instance,
+        )
+
+        self.assertIsInstance(widget, AttachmentviewerWidget)
+        self.assertEqual(len(self.wm), 1 + 1)
+
     def test_attachment_widget_with_associations_using_widget_manager(self):
         photo_property = self.project.property("Picture")
 
         widget = self.wm.add_attachmentviewer_widget(
-            widget_type=WidgetTypes.ATTACHMENTVIEWER,
             title="Attachment Viewer",
             attachment_property=photo_property,
         )
@@ -281,6 +281,18 @@ class TestWidgetManagerInActivity(TestBetamax):
         self.assertIsInstance(widget, AttachmentviewerWidget)
         self.assertEqual(len(self.wm), 1 + 1)
 
+    def test_attachment_widget_with_editable_association(self):
+        photo_property = self.project.property("Picture")
+
+        widget = self.wm.add_attachmentviewer_widget(
+            title="Attachment Viewer",
+            attachment_property=photo_property,
+            editable=True,
+        )
+
+        self.assertIsInstance(widget, AttachmentviewerWidget)
+        self.assertEqual(len(self.wm), 1 + 1)
+
     def test_add_super_grid_widget(self):
         part_model = self.project.model(name='Wheel')
         parent_instance = self.project.part(name='Bike')
@@ -337,15 +349,6 @@ class TestWidgetManagerInActivity(TestBetamax):
         self.assertIsInstance(widget, FilteredgridWidget)
         self.assertEqual(len(self.wm), 1 + 1)
 
-    def test_add_attachment_widget(self):
-        picture_instance = self.project.part('Bike').property('Picture')
-        widget = self.wm.add_attachmentviewer_widget(
-            attachment_property=picture_instance
-        )
-
-        self.assertIsInstance(widget, AttachmentviewerWidget)
-        self.assertEqual(len(self.wm), 1 + 1)
-
     def test_add_propertygrid_widget(self):
         bike_part = self.project.part(name='Bike')
         widget = self.wm.add_propertygrid_widget(
@@ -382,17 +385,26 @@ class TestWidgetManagerInActivity(TestBetamax):
         # setUp
         bike_part = self.project.part(name='Bike')
         picture = bike_part.property(name='Picture')
+        process = self.project.activities(activity_type=ActivityType.PROCESS)[0]
 
-        widget1 = self.wm.add_card_widget(title="Some title", description='Some description',
-                                          link='www.ke-chain.com', link_target=LinkTargets.NEW_TAB)
-        widget2 = self.wm.add_card_widget(image=picture, title=False,
+        widget1 = self.wm.add_card_widget(title="Some title", description='Some description')
+        widget2 = self.wm.add_card_widget(image=picture, title=False, image_fit=ImageFitValue.COVER,
                                           link=self.task.id, link_target=LinkTargets.SAME_TAB)
+        widget3 = self.wm.add_card_widget(title='Tree view', description='Process opens in tree view',
+                                          link=process)
 
         # testing
-        self.assertEqual(len(self.wm), 1 + 2)
+        self.assertEqual(len(self.wm), 1 + 3)
 
         self.assertIsInstance(widget1, CardWidget)
+        self.assertIsNone(widget1.meta.get('customLink'))
+
         self.assertIsInstance(widget2, CardWidget)
+        self.assertEqual(ImageFitValue.COVER, widget2.meta.get('imageFit'))
+        self.assertEqual(CardWidgetLinkTarget.SAME_TAB, widget2.meta.get('linkTarget'))
+
+        self.assertIsInstance(widget3, CardWidget)
+        self.assertEqual(CardWidgetLinkValue.TREE_VIEW, widget3.meta.get('showLinkValue'))
 
         with self.assertRaises(IllegalArgumentError):
             self.wm.add_card_widget(title=12)
@@ -651,20 +663,6 @@ class TestWidgetManagerInActivity(TestBetamax):
         # tearDown
         [w.delete() for w in new_widgets]
 
-    def test_compatibility_functions(self):
-        """Testing various compatibility function for equivalence to the 'customization' in WIM1/PIM1"""
-        for deprecated_method in [
-            'add_text_widget',
-            'add_super_grid_widget',
-            'add_property_grid_widget',
-            'add_paginated_grid_widget',
-            'add_script_widget',
-            'add_attachment_viewer_widget',
-            'add_navigation_bar_widget',
-        ]:
-            with self.subTest(msg=deprecated_method):
-                self.assertTrue(hasattr(self.wm, deprecated_method))
-
 
 class TestWidgetNavigationBarWidget(TestBetamax):
 
@@ -694,7 +692,7 @@ class TestWidgetNavigationBarWidget(TestBetamax):
         widget = self.wm.add_tasknavigationbar_widget(
             activities=self.nav_bar_config,
             title="Navbar",
-            alignment=NavigationBarAlignment.LEFT
+            alignment=Alignment.LEFT
         )
 
         self.assertIsInstance(widget, TasknavigationbarWidget)
@@ -712,7 +710,7 @@ class TestWidgetNavigationBarWidget(TestBetamax):
 
         self.wm.add_tasknavigationbar_widget(
             activities=self.nav_bar_config,
-            alignment=NavigationBarAlignment.LEFT,
+            alignment=Alignment.LEFT,
         )
 
         self.assertEqual(original_bar, self.nav_bar_config)
@@ -723,7 +721,7 @@ class TestWidgetNavigationBarWidget(TestBetamax):
         with self.assertRaises(IllegalArgumentError):
             self.wm.add_tasknavigationbar_widget(
                 activities=self.nav_bar_config,
-                alignment=NavigationBarAlignment.LEFT,
+                alignment=Alignment.LEFT,
             )
 
     def test_add_navbar_external_link(self):
@@ -735,7 +733,7 @@ class TestWidgetNavigationBarWidget(TestBetamax):
 
         widget = self.wm.add_tasknavigationbar_widget(
             activities=self.nav_bar_config,
-            alignment=NavigationBarAlignment.LEFT,
+            alignment=Alignment.LEFT,
         )
 
         self.assertEqual(widget.meta['taskButtons'][0]['link'], link)
@@ -746,7 +744,7 @@ class TestWidgetNavigationBarWidget(TestBetamax):
 
         widget = self.wm.add_tasknavigationbar_widget(
             activities=self.nav_bar_config,
-            alignment=NavigationBarAlignment.LEFT,
+            alignment=Alignment.LEFT,
         )
 
         self.assertTrue(widget.meta['taskButtons'][0]['isDisabled'])
